@@ -14,42 +14,6 @@ from tqdm import tqdm
 from collections import Counter
 from huggingface_hub.utils._errors import HTTPError
 download('stopwords')
-
-
-def preprocess(sentence: str, remove_punct: bool, remove_stop_words: bool, stemm: bool, lang: str='en') -> str: 
-    if lang.lower() == 'en':
-        ps = PorterStemmer()
-        # remove punctuations
-        if not remove_punct:
-            sentence = sentence.translate(str.maketrans('', '', punctuation))
-        # remove stop words and stem
-        if remove_stop_words and stemm:
-            stop_words = stopwords.words('english')
-            return ' '.join([ps.stem(w) for w in sentence.lower().split() if w not in stop_words])
-        # stem only
-        elif not remove_stop_words and stemm:
-            return ' '.join([ps.stem(w) for w in sentence.lower().split()])
-        else:
-            # lower case and remove extra white spaces
-            return ' '.join([w for w in sentence.lower().split()])
-    elif lang.lower() == 'ar':
-        st = ISRIStemmer()
-        # remove punctuations
-        if not remove_punct:
-            sentence = sentence.translate(str.maketrans('', '', punctuation))
-        # remove stop words and stem
-        if remove_stop_words and stemm:
-            download('stopwords')
-            stop_words = stopwords.words('arabic')
-            return ' '.join([st.stem(w) for w in sentence.lower().split() if w not in stop_words])
-        # stem only
-        elif not remove_stop_words and stemm:
-            return ' '.join([st.stem(w) for w in sentence.lower().split()])
-        else:
-            # lower case and remove extra white spaces
-            return ' '.join([w for w in sentence.lower().split()])
-    else:
-        raise Exception('non recognized language please specify either en|ar')
         
 
 def preprocess(sentence: str, remove_punct: bool, remove_stop_words: bool, stemm: bool, lang: str='en') -> str: 
@@ -190,7 +154,7 @@ class sentence_tranformer_checker():
             else:
                 self.model = SentenceTransformer('distiluse-base-multilingual-cased-v1', device=self.device)
                 print('done...')
-
+    
         if encode_target:  
             print('enocding targets: ')
             self.encoded_targets = self.model.encode(self.target_names, batch_size=self.encode_batch, show_progress_bar=True,  normalize_embeddings=True) # encode the targets
@@ -273,10 +237,10 @@ class sentence_tranformer_checker():
 
     def max_cosine_sim(self, encoded_inputs, encoded_targets,  topn, threshold):
         if len(encoded_inputs.shape) == 1:
-            a = a.unsqueeze(0)
+            encoded_inputs = encoded_inputs.unsqueeze(0)
 
         if len(encoded_targets.shape) == 1:
-            b = b.unsqueeze(0)
+            encoded_targets = encoded_targets.unsqueeze(0)
 
         scores = np.matmul(encoded_inputs, encoded_targets.T)
 
